Changes
=======

Unreleased
----------

Version 0.4.0
-------------

Released 2022-11-15

- Add from_pyca_cryptography_key to KEMKey. `#16 <https://github.com/dajiaji/pyhpke/pull/16>`__
- Update dev dependencies.
    - Bump pre-commit/mirrors-mypy to 0.990. `#15 <https://github.com/dajiaji/pyhpke/pull/15>`__
    - Bump tox to 3.27.1. `#15 <https://github.com/dajiaji/pyhpke/pull/15>`__
    - Bump sphinx-rtd-theme to 1.1.1. `#13 <https://github.com/dajiaji/pyhpke/pull/13>`__

Version 0.3.0
-------------

Released 2022-11-05

- First public release.

Version 0.2.0
-------------

Released 2022-10-29

- Experimental release (3) based on https://github.com/ctz/hpke-py.

Version 0.1.1
-------------

Released 2022-10-16

- Experimental release (2) based on https://github.com/ctz/hpke-py.

Version 0.1.0
-------------

Released 2022-10-16

- Experimental release (1) based on https://github.com/ctz/hpke-py.
